const {src, dest, task, parallel, series, watch } = require('gulp');
const { rollup } = require('gulp-rollup-2');
const { nodeResolve } = require( '@rollup/plugin-node-resolve');
const { babel } = require( '@rollup/plugin-babel');
const commonjs  = require( '@rollup/plugin-commonjs');
const iife = require("gulp-iife");
const sass = require('gulp-sass');
const prefix = require('gulp-autoprefixer');
const stripComments = require('gulp-strip-json-comments');
const removeEmptyLines = require('gulp-remove-empty-lines');
// const debug = require('gulp-debug');
// const using = require('gulp-using');

const styleSrcPattern = './src/*.scss';
const jsSrcPattern = './src/*.es6.js';

const jsDist = '../js';
const styleDist = '../css';

// Build JS.
function js() {
  return src(jsSrcPattern)
    .pipe(rollup({
      output: {
        file: 'worldmap.js',
        name: 'worldmap',
        format: 'cjs'
      },
      plugins: [babel({
        "babelHelpers": 'runtime',
        "exclude": "node_modules/**",
        "presets": [["@babel/preset-env", {
          "useBuiltIns": false
        }]],
        "plugins": [
          ["@babel/plugin-transform-runtime", {
            "runtimeHelpers": true
          }]
        ]
      }), nodeResolve(), commonjs()] }))
    .pipe(removeEmptyLines())
    .pipe(stripComments())
    .pipe(iife())
    // .pipe(debug({minimal: false}))
    // .pipe(using())
    .pipe(dest(jsDist));
}

// Build styles.
function scss() {
  return src(styleSrcPattern)
    .pipe(sass({
      errLogToConsole: false,
      onError: function(err) {
        console.log(err);
      }
    }))
    .pipe(stripComments())
    .pipe(prefix())
    // .pipe(debug({minimal: false}))
    // .pipe(using())
    .pipe(dest(styleDist));
}

// Gulp tasks.
// :-$ gulp <taskname>

task('styles', scss);

task('js', js);

task('watch', () => {
  watch(styleSrcPattern, parallel('styles'));
  watch(jsSrcPattern, parallel('js'));
});

task('default', series('styles', 'js'));
